==> v0.01.zip: hugo/content/de/Impressum.md <==
---
title: "Impressum"
date: 2021-02-04T10:10:53+01:00
draft: false
---
[![English](/eng.png)](/en/Imprint)

Diese Webseite wird vom FraLUG e.V. betrieben:

Frankfurter Linux User Group (FraLUG) e.V.   
c/o Jochen Schade   
Landgrafenring 14b   
63073 Offenbach   

Eintragung beim Amtsgericht Frankfurt, Vereinsregister: 14628

Vertreten durch den Vorstand:   
Jens Kühnel   
Jochen Schade   
Dr. Christoph Zimmermann   

<svg class="icon email"><use xlink:href="#email"></use></svg> info AT lugfrankfurt PUNKT de

Bei Problemen ist der Web-Hoster erreichbar! Siehe [hier](http://www.jekkt.com/impressum.php)

-----

## Disclaimer

### Haftungsausschluss

Der Zugang und die Benutzung der Webseite der Frankfurter Linux User Group e.V. geschehen auf eigene Gefahr des Benutzers. Der Betreiber übernimmt keine Verantwortung für die Inhalte und Beiträge. Der Betreiber distanziert sich ausdrücklich von allen Inhalten, die möglicherweise straf- oder haftungsrechtlich relevant sind oder gegen die guten Sitten verstoßen und behält sich vor, Beiträge oder Links mit entsprechendem Inhalt unverzüglich zu löschen. Der Betreiber ist nicht verantwortlich und übernimmt keinerlei Haftung für Schäden, u.a. für direkte, indirekte, zufällige, vorab konkret zu bestimmende oder Folgeschäden, die angeblich durch den oder in Verbindung mit dem Zugang und/oder der Benutzung dieser Webseite aufgetreten sind.

### Hinweis an Rechteinhaber

Autoren sind aufgerufen, alle Inhalte, die sie zu dieser Webseite beisteuern, nach bestem Wissen zu erstellen. Die Betreiber weisen Autoren darauf hin, kein Material zu verwenden, das Urheberrechten Dritter unterliegt. Aufgrund der Art dieser Webseite kann es nicht ausgeschlossen werden, daß Material eingebracht wird, das bestehende Schutzrechte verletzt und das nicht sofort als solches erkannt wird. Entsprechende Urheberrechtsverletzungen bitten wir sofort dem Vorstand (Kontakt siehe Impressum) anzuzeigen, bei Rechtsverletzungen werden wir dementsprechende Inhalte sofort entfernen.

### Haftung für Links

Diese Webseite enthält Links zu externen Webseiten Dritter, auf deren Inhalte wir keinen Einfluss haben. Deshalb können wir für diese fremden Inhalte auch keine Gewähr übernehmen. Für die Inhalte der verlinkten Seiten ist stets der jeweilige Anbieter oder Betreiber der Seiten verantwortlich. Wir bitten sämtliche Autoren dieser Webseite, keinerlei Links auf Webseiten mit rechtswidrigem Inhalt einzufügen und bei Anlegen eines Links die verlinkte Webseite dementsprechend zu überprüfen. Eine permanente inhaltliche Kontrolle der verlinkten Seiten ist ohne konkrete Anhaltspunkte einer Rechtsverletzung nicht zumutbar. Bei Bekanntwerden von Rechtsverletzungen werden wir derartige Links umgehend entfernen.

### Datenschutz

Die Nutzung unserer Webseite ist in der Regel ohne Angabe personenbezogener Daten möglich. Soweit auf unseren Seiten personenbezogene Daten (beispielsweise Name, Anschrift oder eMail-Adressen) erhoben werden, erfolgt dies, soweit möglich, stets auf freiwilliger Basis. Diese Daten werden ohne Ihre ausdrückliche Zustimmung nicht an Dritte weitergegeben.

Wir weisen darauf hin, dass die Datenübertragung im Internet (z.B. bei der Kommunikation per E-Mail) Sicherheitslücken aufweisen kann. Ein lückenloser Schutz der Daten vor dem Zugriff durch Dritte ist nicht möglich.

Der Nutzung von im Rahmen der Impressumspflicht veröffentlichten Kontaktdaten durch Dritte zur Übersendung von nicht ausdrücklich angeforderter Werbung und Informationsmaterialien wird hiermit ausdrücklich widersprochen. Die Betreiber der Seiten behalten sich ausdrücklich rechtliche Schritte im Falle der unverlangten Zusendung von Werbeinformationen, etwa durch Spam-Mails, vor.

### Rechtswirksamkeit dieses Haftungsausschlusses

Dieser Disclaimer ist als Teil des Internetangebotes zu betrachten, von dem aus auf diese Seite verwiesen wurde. Sofern Teile oder einzelne Formulierungen dieses Textes der geltenden Rechtslage nicht, nicht mehr oder nicht vollständig entsprechen sollten, bleiben die übrigen Teile des Dokumentes in ihrem Inhalt und ihrer Gültigkeit davon unberührt.

==> v0.03.zip: hugo/content/de/Impressum.md <==
---
title: "Impressum"
date: 2021-02-04T10:10:53+01:00
draft: false
---
[![English](/eng.png#floatright)](/en/Imprint)

Diese Webseite wird vom FraLUG e.V. betrieben:

Frankfurter Linux User Group (FraLUG) e.V.   
c/o Jochen Schade   
Landgrafenring 14b   
63073 Offenbach   

Eintragung beim Amtsgericht Frankfurt, Vereinsregister: 14628

Vertreten durch den Vorstand:   
Jens Kühnel   
Jochen Schade   
Dr. Christoph Zimmermann   

<svg class="icon email"><use xlink:href="#email"></use></svg> info AT lugfrankfurt PUNKT de

Bei Problemen ist der Web-Hoster erreichbar! Siehe {{<tabref href="http://www.jekkt.com/impressum.php" title="Link">}}

-----

## Disclaimer

### Haftungsausschluss

Der Zugang und die Benutzung der Webseite der Frankfurter Linux User Group e.V. geschehen auf eigene Gefahr des Benutzers. Der Betreiber übernimmt keine Verantwortung für die Inhalte und Beiträge. Der Betreiber distanziert sich ausdrücklich von allen Inhalten, die möglicherweise straf- oder haftungsrechtlich relevant sind oder gegen die guten Sitten verstoßen und behält sich vor, Beiträge oder Links mit entsprechendem Inhalt unverzüglich zu löschen. Der Betreiber ist nicht verantwortlich und übernimmt keinerlei Haftung für Schäden, u.a. für direkte, indirekte, zufällige, vorab konkret zu bestimmende oder Folgeschäden, die angeblich durch den oder in Verbindung mit dem Zugang und/oder der Benutzung dieser Webseite aufgetreten sind.

### Hinweis an Rechteinhaber

Autoren sind aufgerufen, alle Inhalte, die sie zu dieser Webseite beisteuern, nach bestem Wissen zu erstellen. Die Betreiber weisen Autoren darauf hin, kein Material zu verwenden, das Urheberrechten Dritter unterliegt. Aufgrund der Art dieser Webseite kann es nicht ausgeschlossen werden, daß Material eingebracht wird, das bestehende Schutzrechte verletzt und das nicht sofort als solches erkannt wird. Entsprechende Urheberrechtsverletzungen bitten wir sofort dem Vorstand (Kontakt siehe Impressum) anzuzeigen, bei Rechtsverletzungen werden wir dementsprechende Inhalte sofort entfernen.

### Haftung für Links

Diese Webseite enthält Links zu externen Webseiten Dritter, auf deren Inhalte wir keinen Einfluss haben. Deshalb können wir für diese fremden Inhalte auch keine Gewähr übernehmen. Für die Inhalte der verlinkten Seiten ist stets der jeweilige Anbieter oder Betreiber der Seiten verantwortlich. Wir bitten sämtliche Autoren dieser Webseite, keinerlei Links auf Webseiten mit rechtswidrigem Inhalt einzufügen und bei Anlegen eines Links die verlinkte Webseite dementsprechend zu überprüfen. Eine permanente inhaltliche Kontrolle der verlinkten Seiten ist ohne konkrete Anhaltspunkte einer Rechtsverletzung nicht zumutbar. Bei Bekanntwerden von Rechtsverletzungen werden wir derartige Links umgehend entfernen.

### Datenschutz

Die Nutzung unserer Webseite ist in der Regel ohne Angabe personenbezogener Daten möglich. Soweit auf unseren Seiten personenbezogene Daten (beispielsweise Name, Anschrift oder eMail-Adressen) erhoben werden, erfolgt dies, soweit möglich, stets auf freiwilliger Basis. Diese Daten werden ohne Ihre ausdrückliche Zustimmung nicht an Dritte weitergegeben.

Wir weisen darauf hin, dass die Datenübertragung im Internet (z.B. bei der Kommunikation per E-Mail) Sicherheitslücken aufweisen kann. Ein lückenloser Schutz der Daten vor dem Zugriff durch Dritte ist nicht möglich.

Der Nutzung von im Rahmen der Impressumspflicht veröffentlichten Kontaktdaten durch Dritte zur Übersendung von nicht ausdrücklich angeforderter Werbung und Informationsmaterialien wird hiermit ausdrücklich widersprochen. Die Betreiber der Seiten behalten sich ausdrücklich rechtliche Schritte im Falle der unverlangten Zusendung von Werbeinformationen, etwa durch Spam-Mails, vor.

### Rechtswirksamkeit dieses Haftungsausschlusses

Dieser Disclaimer ist als Teil des Internetangebotes zu betrachten, von dem aus auf diese Seite verwiesen wurde. Sofern Teile oder einzelne Formulierungen dieses Textes der geltenden Rechtslage nicht, nicht mehr oder nicht vollständig entsprechen sollten, bleiben die übrigen Teile des Dokumentes in ihrem Inhalt und ihrer Gültigkeit davon unberührt.
